# AutomationScriptResult

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**python_enabled** | **bool** |  | [optional] 
**scripts** | [**list[AutomationScriptAPI]**](AutomationScriptAPI.md) |  | [optional] 
**selected_script** | **dict(str, object)** |  | [optional] 
**suggestions** | **list[str]** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


